from setuptools import setup

setup(name='bi_ga_dist',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['bi_ga_dist'],
      author="Taha B Uyar",
      zip_safe=False)
